@@ -2,7 +2,7 @@ package Memcached::libmemcached::memcached_verbosity;
 
 =head1 NAME
 
-memcached_verbosity
+memcached_verbosity - Modifiy verbosity of servers
 
 =head1 LIBRARY
 
@@ -12,8 +12,9 @@ C Client Library for memcached (libmemcached, -lmemcached)
 
   #include <memcached.h>
 
-  memcached_return memcached_verbosity (memcached_st *ptr,
-                                        unsigned int verbosity);
+  memcached_return_t 
+    memcached_verbosity (memcached_st *ptr,
+                         unsigned int verbosity);
 
 =head1 DESCRIPTION
 
@@ -22,14 +23,14 @@ memcached(1) servers referenced in the C<memcached_st> parameter.
 
 =head1 RETURN
 
-A value of type C<memcached_return> is returned
+A value of type C<memcached_return_t> is returned
 On success that value will be C<MEMCACHED_SUCCESS>.
 Use memcached_strerror() to translate this value to a printable string.
 
 =head1 HOME
 
 To find out more information please check:
-L<http://tangent.org/552/libmemcached.html>
+L<https://launchpad.net/libmemcached>
 
 =head1 AUTHOR
 
